<?php

namespace App\Http\Controllers;
use App\Producto;
use App\ProductoGrupoTerapeutico;
use App\ProductoLaboratorio;
use App\ProductoLinea;
use App\ProductoMarca;
use App\ListaPrecios;


use Illuminate\Http\Request;

class ProductosController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //        
        $productos=Producto::with('grupo_terapeutico')
                    ->with('laboratorio')
                    ->with('linea')
                    ->with('marca')
                    ->get();
        return view('productos.lista',compact('productos'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
        $grupoTerapeuticos=ProductoGrupoTerapeutico::all();
        $laboratorios=ProductoLaboratorio::all();
        $lineas=ProductoLinea::all();
        $marcas=ProductoMarca::all();
        return view('productos.nuevo',compact('grupoTerapeuticos','laboratorios','lineas','marcas'));

    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
        $where = [
            'nombre' => $request->nombre,
            'id_linea' => $request->id_linea,
            'id_laboratorio' => $request->id_laboratorio,
            'id_marca' => $request->id_marca,
            'id_grupo_terapeutico' => $request->id_grupo_terapeutico,
            'id_tipo' => $request->id_tipo
        ];
        $productos=Producto::where($where)->first();
        
        if($productos){
            $arrResponse = [
                'message' => 'El Producto ya existe'
            ];
            return redirect()->route('productos.listado')->with($arrResponse);
            dd();
        }
        $producto = new Producto();
        $producto->nombre = $request->nombre;
        $producto->id_laboratorio = $request->id_laboratorio;
        $producto->id_linea = $request->id_linea;
        $producto->id_tipo = $request->id_tipo;
        $producto->id_marca = $request->id_marca;
        $producto->id_grupo_terapeutico = $request->id_grupo_terapeutico;

        $producto->save();
        $arrResponse = [
            'message' => 'Producto guardado correctamente'
        ];
        return redirect()->route('productos.listado')->with($arrResponse);
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(Producto $producto)
    {
        //
        $grupoTerapeuticos=ProductoGrupoTerapeutico::all();
        $laboratorios=ProductoLaboratorio::all();
        $lineas=ProductoLinea::all();
        $marcas=ProductoMarca::all();
        return view('productos.editar',compact('grupoTerapeuticos','laboratorios','lineas','marcas','producto'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Producto $producto)
    {
        //
        $producto->nombre = $request->nombre;
        $producto->id_laboratorio = $request->id_laboratorio;
        $producto->id_linea = $request->id_linea;
        $producto->id_tipo = $request->id_tipo;
        $producto->id_marca = $request->id_marca;
        $producto->id_grupo_terapeutico = $request->id_grupo_terapeutico;

        $producto->update();
        $arrResponse = [
            'message' => 'Producto actualizado correctamente'
        ];
        return redirect()->route('productos.listado')->with($arrResponse);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
        Producto::destroy($id);
        $arrResponse = [
            'message' => 'Producto eliminado correctamente'
        ];
        return redirect()->route('productos.listado')->with($arrResponse);
    }
    //Listado de precios por AJAX
    public function listadoPrecios(Request $request){
        $listas=ListaPrecios::with('listado_precios')->find($request->id_lista);
        return response($listas);
    }
}
