<?php

namespace App\Http\Controllers;
use Illuminate\Support\Facades\Auth;
use App\Apm;
use App\CodigoPostal;
use App\Especialidad;
use App\Linea;
use App\TipoSocio;
use App\Clasificacion;
use App\Departamento;
use App\Gira;
use App\Socio;
use App\SocioBorrador;
use App\Pais;
use App\LineaSocio;
use App\LineaSocioBorrador;
use App\ListaPrecios;
use App\Municipio;
use Illuminate\Support\Facades\DB;

use Illuminate\Http\Request;

class SociosController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //
        $socios=Socio::with('lineas')
                ->with('especialidad')
                ->with('tipoSocio')
                ->with('clasificacion')
                ->with('codigo')
                ->get();
        return view('socios.lista',compact('socios'));
    }
    public function sociosInactivos()
    {
        //
        $socios=SocioBorrador::with('lineas')
                ->with('especialidad')
                ->with('tipoSocio')
                ->with('clasificacion')
                ->get();

        return view('socios.lista_inactiva',compact('socios'));
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //

        $lineas=Linea::all();
        $pais=Pais::all();
        $especialidades=Especialidad::all();
        $tipoSocio=TipoSocio::all();
        $listas=ListaPrecios::all();
        $clasificaciones=Clasificacion::all();
        return view('socios.nuevo',compact('lineas','especialidades','tipoSocio','clasificaciones','listas','pais'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
        $orgDate = $request->fecha_cumpleanos;
        $newDate = date("Y-m-d", strtotime($orgDate));

        $socio = new Socio();
        $socio->nit_socio = $request->nit;
        $socio->dpi = $request->dpi;
        $socio->telefono_oficina_socio = $request->telefono;
        $socio->telefono_movil_socio = $request->celular;
        $socio->numero_colegiado_socio = $request->colegiado;
        $socio->primer_nombre_socio = $request->primer_nombre;
        $socio->segundo_nombre_socio = $request->segundo_nombre;
        $socio->primer_apellido_socio = $request->primer_apellido;
        $socio->segundo_apellido_socio = $request->segundo_apellido;
        $socio->nombre_comercial_socio = $request->nombre_comercial;
        $socio->id_especialidad = $request->especialidad;
        $socio->id_codigo_postal = $request->id_codigo_postal;
        $socio->id_gira = $request->id_gira;
        $socio->cod_diamante = $request->diamante;
        $socio->cod_elvis = $request->elvis;
        $socio->id_tipo_socio = $request->tipo_socio;
        $socio->direccion = $request->direccion;
        $socio->fecha_cumpleanos = $request->$newDate;
        $socio->hobby = $request->hobby;
        $socio->id_lista = $request->id_lista;
        $socio->id_clasificacion = $request->clasificación;
        $socio->id_user = Auth::id();
        if(Auth::user()->id_role==2){
            $socio->status=1;
        }else{
            $socio->status=0;
        }
        $socio->save();

        if($socio->id){

            foreach($request->lineas as $linea){
                $lineaSocio = new LineaSocio();
                $lineaSocio->id_socio = $socio->id;
                $lineaSocio->id_user = Auth::id();
                $lineaSocio->id_linea = $linea;
                $lineaSocio->save();
            }
            $arrResponse = [
                'message' => 'Socio guardado correctamente'
            ];
            if(Auth::user()->id_role==2){
                return redirect()->route('socios.crear')->with($arrResponse);
            }
            return redirect()->route('socios.index')->with($arrResponse);

        }else{
            $arrResponse = [
                'message' => 'Error al guardar al socio'
            ];
            if(Auth::user()->id_role==2){
                return redirect()->route('socios.crear')->with($arrResponse);
            }
            return redirect()->route('socios.index')->with($arrResponse);
        }
        $arrResponse = [
            'message' => 'Error al guardar al socio'
        ];
        if(Auth::user()->id_role==2){
            return redirect()->route('socios.crear')->with($arrResponse);
        }
        return redirect()->route('socios.index')->with($arrResponse);
        dd();
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
        $socio=Socio::where('id',$id)->with('codigo')->with('lineas')->first();
        //dd($socio);
        $linea_socio=LineaSocio::where('id_socio',$id)->get();
        //dd($linea_socio);
        $lineas=Linea::all();
        $pais=Pais::all();
        $especialidades=Especialidad::all();
        $tipoSocio=TipoSocio::all();
        $listas=ListaPrecios::all();
        $clasificaciones=Clasificacion::all();
        return view('socios.editar',compact('lineas','especialidades','tipoSocio','clasificaciones','listas','pais','socio','linea_socio'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Socio $socio)
    {
        //
        $orgDate = $request->fecha_cumpleanos;
        $newDate = date("Y-m-d", strtotime($orgDate));
        $socio->nit_socio = $request->nit;
        $socio->dpi = $request->dpi;
        $socio->telefono_oficina_socio = $request->telefono;
        $socio->telefono_movil_socio = $request->celular;
        $socio->numero_colegiado_socio = $request->colegiado;
        $socio->primer_nombre_socio = $request->primer_nombre;
        $socio->segundo_nombre_socio = $request->segundo_nombre;
        $socio->primer_apellido_socio = $request->primer_apellido;
        $socio->segundo_apellido_socio = $request->segundo_apellido;
        $socio->nombre_comercial_socio = $request->nombre_comercial;
        $socio->id_especialidad = $request->especialidad;
        if($request->id_codigo_postal){
            $socio->id_codigo_postal = $request->id_codigo_postal;
            $socio->id_gira = $request->id_gira;
        }

        $socio->cod_diamante = $request->diamante;
        $socio->cod_elvis = $request->elvis;
        $socio->id_tipo_socio = $request->tipo_socio;
        $socio->direccion = $request->direccion;
        $socio->fecha_cumpleanos = $newDate;
        $socio->hobby = $request->hobby;
        $socio->id_lista = $request->id_lista;
        $socio->id_clasificacion = $request->clasificación;
        $socio->id_user = Auth::id();
        if(Auth::user()->id_role==2){
            $socio->status=1;
        }else{
            $socio->status=0;
        }
        $socio->update();

        LineaSocio::where('id_socio', $socio->id)->delete();
        foreach($request->lineas as $linea){
            $lineaSocio = new LineaSocio();
            $lineaSocio->id_socio = $socio->id;
            $lineaSocio->id_user = Auth::id();
            $lineaSocio->id_linea = $linea;
            $lineaSocio->save();
        }
        $arrResponse = [
            'message' => 'Socio actualizado correctamente'
        ];
        if(Auth::user()->id_role==2){
            return redirect()->route('socios.crear')->with($arrResponse);
        }
        return redirect()->route('socios.index')->with($arrResponse);

        dd();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Socio $socio)
    {
        //
        LineaSocio::destroy($socio->id_socio);
        Socio::destroy($socio->id);
        $arrResponse = [
            'message' => 'Socio eliminado correctamente'
        ];
        return redirect()->route('socios.index')->with($arrResponse);
    }

    public function codigosArea(){

        $codigoPostal['data']=CodigoPostal::with('pais')
                ->with('departamento')
                ->with('municipio')
                ->with('region')
                ->with('gira')
                ->with('zona')
                ->get();

        return response($codigoPostal);
    }
    public function listadoSociosA()
    {
        dd();
    }
    public function listadoSocios()
    {
        $idAPM=Auth::id();
        $apm=Apm::where('id_user',$idAPM)->first();
        $idLinea=$apm->id_linea;

        $socios=DB::table('crm_linea_socio')
                            ->where('crm_linea_socio.id_linea',$idLinea)
                            ->join('crm_socio', 'crm_linea_socio.id_socio', 'crm_socio.id')
                            ->where('crm_socio.status',0)
                            ->get();
        return view('socios.lista_socios',compact('socios'));
    }

    public function createSocioApm()
    {
        //

        $lineas=Linea::all();
        $departamentos=Departamento::all();
        $municipios=Municipio::all();
        $pais=Pais::all();
        $especialidades=Especialidad::all();
        $tipoSocio=TipoSocio::all();
        $listas=ListaPrecios::all();
        $clasificaciones=Clasificacion::all();
        return view('ficha_socio.nuevo_socio',compact('lineas','municipios','departamentos','especialidades','tipoSocio','clasificaciones','listas','pais'));
    }
    public function storeSocioApm(Request $request)
    {
        //

        $orgDate = $request->fecha_cumpleanos;
        $newDate = date("Y-m-d", strtotime($orgDate));

        $socio = new SocioBorrador();
        $socio->nit_socio = $request->nit;
        $socio->dpi = $request->dpi;
        $socio->telefono_oficina_socio = $request->telefono;
        $socio->telefono_movil_socio = $request->celular;
        $socio->numero_colegiado_socio = $request->colegiado;
        $socio->primer_nombre_socio = $request->primer_nombre;
        $socio->segundo_nombre_socio = $request->segundo_nombre;
        $socio->primer_apellido_socio = $request->primer_apellido;
        $socio->segundo_apellido_socio = $request->segundo_apellido;
        $socio->nombre_comercial_socio = $request->nombre_comercial;
        $socio->id_especialidad = $request->especialidad;
        $socio->id_codigo_postal = $request->id_codigo_postal;
        $socio->id_gira = $request->id_gira;
        $socio->cod_diamante = $request->diamante;
        $socio->cod_elvis = $request->elvis;
        $socio->id_tipo_socio = $request->tipo_socio;
        $socio->direccion = $request->direccion;
        $socio->fecha_cumpleanos = $request->$newDate;
        $socio->hobby = $request->hobby;
        $socio->id_lista = $request->id_lista;
        $socio->id_clasificacion = $request->clasificación;
        $socio->id_user = Auth::id();
        $socio->status=1;

        $socio->save();

        if($socio->id){

            foreach($request->lineas as $linea){
                $lineaSocio = new LineaSocioBorrador();
                $lineaSocio->id_socio = $socio->id;
                $lineaSocio->id_user = Auth::id();
                $lineaSocio->id_linea = $linea;
                $lineaSocio->save();
            }
            $arrResponse = [
                'message' => 'Socio guardado correctamente'
            ];
            return redirect()->route('socios.crear_por_apm')->with($arrResponse);

        }else{
            $arrResponse = [
                'message' => 'Error al guardar al socio'
            ];
            return redirect()->route('socios.crear_por_apm')->with($arrResponse);
        }
        $arrResponse = [
            'message' => 'Error al guardar al socio'
        ];

        return redirect()->route('socios.crear_por_apm')->with($arrResponse);
        dd();
    }
    public function editAprobacion($id)
    {
        //
        $socio=SocioBorrador::where('id',$id)->with('codigo')->with('lineas')->first();
        //dd($socio);
        $linea_socio=LineaSocioBorrador::where('id_socio',$id)->get();
        //dd($linea_socio);
        $lineas=Linea::all();
        $pais=Pais::all();
        $especialidades=Especialidad::all();
        $tipoSocio=TipoSocio::all();
        $listas=ListaPrecios::all();
        $clasificaciones=Clasificacion::all();
        return view('socios.editar_borrador',compact('lineas','especialidades','tipoSocio','clasificaciones','listas','pais','socio','linea_socio'));
    }
    public function nuevaAprobacion(Request $request, SocioBorrador $idBorrador)
    {
        //
        $orgDate = $request->fecha_cumpleanos;
        $newDate = date("Y-m-d", strtotime($orgDate));

        $socio = new Socio();
        $socio->nit_socio = $request->nit;
        $socio->dpi = $request->dpi;
        $socio->telefono_oficina_socio = $request->telefono;
        $socio->telefono_movil_socio = $request->celular;
        $socio->numero_colegiado_socio = $request->colegiado;
        $socio->primer_nombre_socio = $request->primer_nombre;
        $socio->segundo_nombre_socio = $request->segundo_nombre;
        $socio->primer_apellido_socio = $request->primer_apellido;
        $socio->segundo_apellido_socio = $request->segundo_apellido;
        $socio->nombre_comercial_socio = $request->nombre_comercial;
        $socio->id_especialidad = $request->especialidad;
        $socio->id_codigo_postal = $request->id_codigo_postal;
        $socio->id_gira = $request->id_gira;
        $socio->cod_diamante = $request->diamante;
        $socio->cod_elvis = $request->elvis;
        $socio->id_tipo_socio = $request->tipo_socio;
        $socio->direccion = $request->direccion;
        $socio->fecha_cumpleanos = $request->$newDate;
        $socio->hobby = $request->hobby;
        $socio->id_lista = $request->id_lista;
        $socio->id_clasificacion = $request->clasificación;
        $socio->id_user = Auth::id();
        if(Auth::user()->id_role==2){
            $socio->status=1;
        }else{
            $socio->status=0;
        }
        $socio->save();

        if($socio->id){

            foreach($request->lineas as $linea){
                $lineaSocio = new LineaSocio();
                $lineaSocio->id_socio = $socio->id;
                $lineaSocio->id_user = Auth::id();
                $lineaSocio->id_linea = $linea;
                $lineaSocio->save();
            }
            $arrResponse = [
                'message' => 'Socio guardado correctamente'
            ];

            LineaSocioBorrador::destroy($idBorrador->id_socio);
            SocioBorrador::destroy($idBorrador->id);
            return redirect()->route('socios.index')->with($arrResponse);

        }else{
            $arrResponse = [
                'message' => 'Error al guardar al socio'
            ];
            if(Auth::user()->id_role==2){
                return redirect()->route('socios.crear')->with($arrResponse);
            }
            return redirect()->route('socios.index')->with($arrResponse);
        }
        $arrResponse = [
            'message' => 'Error al guardar al socio'
        ];
        if(Auth::user()->id_role==2){
            return redirect()->route('socios.crear')->with($arrResponse);
        }
        return redirect()->route('socios.index')->with($arrResponse);
        dd();
    }
    public function destroyAprobacion(Socio $socio)
    {
        //
        LineaSocioBorrador::destroy($socio->id_socio);
        SocioBorrador::destroy($socio->id);
        $arrResponse = [
            'message' => 'Socio eliminado correctamente'
        ];
        return redirect()->route('socio.aprobaciones')->with($arrResponse);
    }
}
